==> pylogger-0.1.tar.gz: pylogger-0.1/comments.py <==
#!/usr/bin/python2

# PyLogger (comments.py)
#
# Tool to add comments to a site. It may seem more complex than
# it needs to be, but I had to do all this because of some
# limitations on Pair.
#
# Written by A.Sajjad Zaidi (http://www.sajjadzaidi.com/)
# Copyright April 2003
#


import os,sys
import string
from string import atoi
import re

# Location of files to be processed into .html pages (.asz files)
DOCROOT = '/home/sajjad/work/sajjadzaidi.com'
# Root URL of the main site
MAINURL = 'http://www.sajjadzaidi.com'
# Location of cgi scripts. Could be the same as MAINURL
CGIURL = 'http://www.gangblog.com/cgi-bin'


# Parse CGI Form and display main page if no arguments given
def parseCGIForm():
	global DOCROOT
	global MAINURL

	import cgi

	form = cgi.FieldStorage()

	# Preview is always dynamic
	if form.has_key('preview'):
		if not form.has_key('email'):
			senderEmail = ''
		else:
			senderEmail = form['email'].value
		if not form.has_key('url'):
			senderURL = ''
		else:
			senderURL = form['url'].value
		if not form.has_key('sender'):
			commentSender = 'Anonymous'
		else:
			commentSender = form['sender'].value
		if not form.has_key('comment'):
			commentBody = ''
		else:
			commentBody = form['comment'].value
		entryID = form['blid'].value
		displayCommentPage(entryID, commentSender, senderEmail, senderURL, commentBody)
	# blogid only appears if the comment link is clicked so
	# just display the current comments or display dynamic comment form
	elif form.has_key('blogid'):
		blogID = form['blogid'].value
		blogYear,blogMonth,fullDate = getIndexData(blogID)
		commentFileName = '%s/%s/%s/comments-%s.asz' %(DOCROOT,blogYear,blogMonth,blogID)
		if os.path.exists(commentFileName):
			commentURL = '%s/%s/%s/comments-%s.html' %(MAINURL,blogYear,blogMonth,blogID)
			printRedirPage(commentURL)
		else:
			displayCommentPage(blogID,'', '', '', '')
	elif form.has_key('confirm'):
		if not form.has_key('email'):
			senderEmail = ''
		else:
			senderEmail = form['email'].value
		if not form.has_key('url'):
			senderURL = ''
		else:
			senderURL = form['url'].value
		if not form.has_key('sender'):
			commentSender = 'Anonymous'
		else:
			commentSender = form['sender'].value
		if not form.has_key('comment'):
			commentBody = ''
		else:
			commentBody = form['comment'].value
		entryID = form['blid'].value
		sendComment(entryID, commentSender, senderEmail, senderURL, commentBody)
	else:
		printRedirPage('%s' % MAINURL)
	return()



# Open index file and get the required info
# This could be replaced by a call to a database
def getIndexData(serialID):
	indexPat = re.compile(r'%s,"([^,]*)","([^,]*)","(.*)"' % serialID)

	indexFile = '/home/sajjad/blogindex'
	fp = open(indexFile)
	blogRecord = fp.readline()
	while blogRecord:
		idxMatch = indexPat.search(blogRecord)
		if idxMatch:
			blogDate = idxMatch.group(1)
			blogTime = idxMatch.group(2)
			blogSubject = idxMatch.group(3)
			break
		blogRecord = fp.readline()
	fp.close()
	
	datePat = re.compile(r'\w* \d*\w\w (\w\w\w)\w* (\d*)')
	dateMatch = datePat.search(blogDate)
	if dateMatch:
		blMonth = string.lower(dateMatch.group(1))
		blYear = dateMatch.group(2)
	else:
		blMonth = 'may'
		blYear = '2003'

	return(blYear,blMonth,blogDate)



def getBlogBody(blogID):
	global DOCROOT

	blogYear,blogMonth,fullDate = getIndexData(blogID)
	blogFileName = "%s/%s/%s/index.asz" % (DOCROOT,blogYear, blogMonth)

	fp = open(blogFileName)
	fullFile = string.join(fp.readlines(),'')
	fp.close()

	blogPat = re.compile(r'<a name="%s"></a>\s*<p><b>([^<]*)</b><br></br>(.*?)<p class="blogend">([^<]+)<' % blogID, re.DOTALL)
	allMatches = blogPat.search(fullFile)
	if allMatches:
		blogSubject = allMatches.group(1)
		fullBlogEntry = allMatches.group(2)
		timeStamp = allMatches.group(3)
	else:
		printFinalPage("<p>Sorry, no blog entry with that ID was found</p>")

	return(blogSubject,fullBlogEntry,timeStamp)



# Preview Page
def displayCommentPage(entryID, commentSender, senderEmail, senderURL, commentBody):
	global CGIURL

	blogSubject,fullBlogEntry,blogTimeStamp = getBlogBody(entryID)

	escBody = string.replace(commentBody,'<','&lt;')
	escBody = string.replace(escBody,'>','&gt;')

	commentBody = string.replace(commentBody,'\n','<br></br>\n')
	todaysDate,currentTime = getTimes()

	blogYear,blogMonth,fullDate = getIndexData(entryID)

	if commentBody == '':
		divSection = ''
	else:
		divSection = '''
								<div>
								<p><b>On %s, at %s, <a href="%s">%s</a> said:</b></p>
								<p>%s</p>
								</div>
''' % (todaysDate, currentTime, senderURL, commentSender, commentBody)

	previewPage = '''<title>Comments for Blog Entry %s</title><h5>%s</h5>
<p><b>%s</b><br></br>
%s
								<p class="blogend">%s </p>
								<hr></hr>
%s
								<form action="%s/comments.py" method="post">
									<input name="blid" type="hidden" value="%s">
									<p><b>Name:</b> <br></br><input name="sender" value="%s"></p>
									<p><b>Email:</b> <br></br><input name="email" value="%s"></p>
									<p><b>Blog URL:</b> <br></br><input name="url" value="%s"></p>
									<p><b>Comment:</b><br></br>
									<textarea cols="50" rows="10" name="comment">%s</textarea>
									<br></br>
									<input value="Send" name="confirm" type="submit"><input value="Preview" name="preview" type="submit"><input value="Cancel" name="cancel" type="submit"></p>
								</form>
''' % (entryID, fullDate, blogSubject, fullBlogEntry, blogTimeStamp, divSection, CGIURL, entryID, commentSender, senderEmail, senderURL, escBody)

	printFinalPage(previewPage)
        return()


# Generate the desired date and time formats for the blog entry
def getTimes():
	import time

	currentHour = time.strftime("%H", time.localtime(time.time()))
	if atoi(currentHour) < 12:
		timeSuffix = 'am'
	else:
		timeSuffix = 'pm'

	currentMinute = time.strftime("%M", time.localtime(time.time()))

	dayOfMonth = time.strftime("%d", time.localtime(time.time()))
	if atoi(dayOfMonth) < 10:
		dayOfMonth = string.replace(dayOfMonth,'0','')
	if dayOfMonth == '1':
		dayOfMonth = '1st';
	elif dayOfMonth == '2':
		dayOfMonth = '2nd';
	elif dayOfMonth == '3':
		dayOfMonth = '3rd';
	elif dayOfMonth == '21':
		dayOfMonth = '21st';
	elif dayOfMonth == '22':
		dayOfMonth = '22nd';
	elif dayOfMonth == '23':
		dayOfMonth = '23rd';
	elif dayOfMonth == '31':
		dayOfMonth = '31st';
	else:
		dayOfMonth = '%sth' % dayOfMonth
	monthOfYear = time.strftime("%B", time.localtime(time.time()))
	decimalYear = time.strftime("%Y", time.localtime(time.time()))

	blogDate = '%s %s %s' % (dayOfMonth, monthOfYear, decimalYear)
	blogTime = '%s:%s%s' % (currentHour, currentMinute, timeSuffix)

	return(blogDate, blogTime)



# Get input from somewhere and insert it in the main page, together with
# the time stamp
def sendComment(blID, commentSender, senderEmail, senderURL, commentBody):
	global DOCROOT
	global MAINURL
	global CGIURL

	todaysDate,currentTime = getTimes()

	commentBody = string.replace(commentBody,'\n','<br></br>\n')
	commentHTML = '''
<div>
<p><b>On %s, at %s, <a href="%s">%s</a> said:</b></p>

<p>%s</p>

</div>

<!-- NEW COMMENTS GO HERE -->''' %(todaysDate, currentTime, senderURL, commentSender, commentBody)

	blogYear,blogMonth,fullDate = getIndexData(blID)
	commentFileName = '%s/%s/%s/comments-%s.asz' %(DOCROOT,blogYear,blogMonth,blID)
	commentURL = '%s/%s/%s/comments-%s.html' %(MAINURL,blogYear,blogMonth,blID)

	if os.path.exists(commentFileName):
		c = open(commentFileName)
		oldComments = string.join(c.readlines(),'')
		c.close()
		newData = string.replace(oldComments,'<!-- NEW COMMENTS GO HERE -->',commentHTML)
		n = open(commentFileName,'w')
		n.write(newData)
		n.close()
	else:
		blogSubject,fullBlogEntry,blogTimeStamp = getBlogBody(blID)
		fullHTMLBlock = '''<title>Comments for Blog Entry %s</title><h5>%s</h5>
<p><b>%s</b><br></br>
%s
								<p class="blogend">%s </p>
								<hr></hr>
%s
								<form action="%s/comments.py" method="post">
									<input name="blid" type="hidden" value="%s">
									<p><b>Name:</b> <br></br><input name="sender"></p>
									<p><b>Email:</b> <br></br><input name="email"></p>
									<p><b>Blog URL:</b> <br></br><input name="url"></p>
									<p><b>Comment:</b><br></br>
									<textarea cols="50" rows="10" name="comment"></textarea>
									<br></br>
									<input value="Send" name="confirm" type="submit"><input value="Preview" name="preview" type="submit"><input value="Cancel" name="cancel" type="submit"></p>
								</form>
''' % (blID, fullDate, blogSubject, fullBlogEntry, blogTimeStamp, commentHTML, CGIURL, blID)

		c = open(commentFileName, 'w')
		c.write(fullHTMLBlock)
		c.close()

	incrementCommentLink(blID)
	webUpdateCommand = 'sudo -u sajjad /home/sajjad/bin/webupdate.py'
	upd = os.popen(webUpdateCommand)
	upd.close()
	mailComment(blID, commentSender, senderEmail, commentURL)
	printRedirPage(commentURL)
	return()



def mailComment(blID, senderName, senderEmail, commentURL):
	import smtplib

	mailBody = '''
Comment from %s on blog entry %s:

%s
''' %(senderName, blID, commentURL)

	smtpServer = 'localhost'
	if senderEmail == '':
		senderEmail = 'webmaster@zaidi.jp'
	fromAddress = '%s' % senderEmail
	toAddress = 'sajjad@zaidi.jp'
	mailSubject = 'Comment from %s' % senderName

	fullMessage = '''From: %s
To: %s
Cc: 
Bcc: 
Subject: %s 
Reply-To: 

%s
''' %(fromAddress, toAddress, mailSubject, mailBody)
	try:
		server = smtplib.SMTP('%s' % smtpServer)
		server.sendmail('%s' % fromAddress, '%s' % toAddress, fullMessage)
		server.quit
	except:
		printFinalPage('<p>Error sending comment. Please contact the webmaster</p>')
	return()



def printFinalPage(pageContent):
	global DOCROOT

	fp = open('%s/template.html' % DOCROOT)
	fullTemplate = string.join(fp.readlines(), '')
	fp.close()
	
	tPat = re.compile(r'<title>([^<]*)</title>')
	titleMatch = tPat.search(pageContent)
	if titleMatch:
		pageTitle = titleMatch.group(1)
		pageContent = string.replace(pageContent, '<title>%s</title>' % pageTitle, '')
	else:
		pageTitle = 'Sajjad\'s Japan Site'

	finalPage = string.replace(fullTemplate, '#INSERT_BODY_HERE#', pageContent)
	finalPage = string.replace(finalPage, '#PUT_TITLE_HERE#', pageTitle)

        print 'Content-type: text/html\n\n'
        print finalPage
	sys.exit(0)
	return()



# Redirect to specified page
def printRedirPage(redirURL):
        mainPageRedirect = '''
<html>
        <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
		<meta http-equiv="refresh" content="0;url=%s">
                <title>Redirect to main page</title>
        </head>
        <body>
        </body>
</html>''' % redirURL
        print 'Content-type: text/html\n\n'
	print mainPageRedirect
	sys.exit(0)
        return()


def incrementCommentLink(blID):
	global DOCROOT

	blogYear,blogMonth,fullDate = getIndexData(blID)
	blogFileName = "%s/%s/%s/index.asz" % (DOCROOT,blogYear, blogMonth)

	fp = open(blogFileName)
	fullFile = string.join(fp.readlines(),'')
	fp.close()

	comPat = re.compile(r'blogid=%s">Comments(.*?)</a>' % blID, re.DOTALL)
	comMatch = comPat.search(fullFile)
	if comMatch:
		matchResult = comMatch.group(1)
		if matchResult == '':
			newCommentNo = 1
			fullFile = string.replace(fullFile,'blogid=%s">Comments</a>' %(blID),'blogid=%s">Comments(%s)</a>' %(blID, newCommentNo))
		else:
			matchResult = string.replace(matchResult,'(','')
			matchResult = string.replace(matchResult,')','')
			oldCommentNo = atoi(matchResult)
			newCommentNo = oldCommentNo + 1
			fullFile = string.replace(fullFile,'blogid=%s">Comments(%s)</a>' %(blID, oldCommentNo),'blogid=%s">Comments(%s)</a>' %(blID, newCommentNo))
		c = open(blogFileName,'w')
		c.write(fullFile)
		c.close()
	return()



###########################################
##                 Start                 ##
###########################################

# Check how we were accessesd
if os.environ.has_key("GATEWAY_INTERFACE"):
	parseCGIForm()

sys.exit(0)

==> pylogger-0.2.tar.gz: pylogger-0.2/comments.py <==
#!/usr/bin/python2

# PyLogger (comments.py)
#
# Tool to add comments to a site. It may seem more complex than
# it needs to be, but I had to do all this because of some
# limitations on Pair.
#
# Written by A.Sajjad Zaidi (http://www.sajjadzaidi.com/)
# Copyright April 2003
#


import os,sys
import string
from string import atoi
import re

# Location of files to be processed into .html pages (.asz files)
DOCROOT = '/home/sajjad/work/sajjadzaidi.com'
# Root URL of the main site
MAINURL = 'http://www.sajjadzaidi.com'
# Location of cgi scripts. Could be the same as MAINURL
CGIURL = 'http://www.gangblog.com/cgi-bin'


def parseCGIForm():
	"""Parse CGI Form and display main page if no arguments given"""

	global DOCROOT
	global MAINURL

	import cgi

	form = cgi.FieldStorage()

	# Preview is always dynamic
	if form.has_key('preview'):
		if not form.has_key('email'):
			senderEmail = ''
		else:
			senderEmail = form['email'].value
		if not form.has_key('url'):
			senderURL = ''
		else:
			senderURL = form['url'].value
		if not form.has_key('sender'):
			commentSender = 'Anonymous'
		else:
			commentSender = form['sender'].value
		if not form.has_key('comment'):
			commentBody = ''
		else:
			commentBody = form['comment'].value
		entryID = form['blid'].value
		displayCommentPage(entryID, commentSender, senderEmail, senderURL, commentBody)
	# blogid only appears if the comment link is clicked so
	# just display the current comments or display dynamic comment form
	elif form.has_key('blogid'):
		blogID = form['blogid'].value
		blogYear,blogMonth,fullDate = getIndexData(blogID)
		commentFileName = '%s/%s/%s/comments-%s.asz' %(DOCROOT,blogYear,blogMonth,blogID)
		if os.path.exists(commentFileName):
			commentURL = '%s/%s/%s/comments-%s.html' %(MAINURL,blogYear,blogMonth,blogID)
			printRedirPage(commentURL)
		else:
			displayCommentPage(blogID,'', '', '', '')
	elif form.has_key('confirm'):
		if not form.has_key('email'):
			senderEmail = ''
		else:
			senderEmail = form['email'].value
		if not form.has_key('url'):
			senderURL = ''
		else:
			senderURL = form['url'].value
		if not form.has_key('sender'):
			commentSender = 'Anonymous'
		else:
			commentSender = form['sender'].value
		if not form.has_key('comment'):
			commentBody = ''
		else:
			commentBody = form['comment'].value
		entryID = form['blid'].value
		sendComment(entryID, commentSender, senderEmail, senderURL, commentBody)
	else:
		printRedirPage('%s' % MAINURL)
	return()



def getIndexData(serialID):
	"""Open index file and get the required info
	This could be replaced by a call to a database"""

	indexPat = re.compile(r'%s,"([^,]*)","([^,]*)","(.*)"' % serialID)

	indexFile = '/home/sajjad/blogindex'
	fp = open(indexFile)
	blogRecord = fp.readline()
	while blogRecord:
		idxMatch = indexPat.search(blogRecord)
		if idxMatch:
			blogDate = idxMatch.group(1)
			blogTime = idxMatch.group(2)
			blogSubject = idxMatch.group(3)
			break
		blogRecord = fp.readline()
	fp.close()
	
	datePat = re.compile(r'\w* \d*\w\w (\w\w\w)\w* (\d*)')
	dateMatch = datePat.search(blogDate)
	if dateMatch:
		blMonth = string.lower(dateMatch.group(1))
		blYear = dateMatch.group(2)
	else:
		blMonth = 'may'
		blYear = '2003'

	return(blYear,blMonth,blogDate)



def getBlogBody(blogID):
	"""Open the existing file and get the body of the blog
	from it"""

	global DOCROOT

	blogYear,blogMonth,fullDate = getIndexData(blogID)
	blogFileName = "%s/%s/%s/index.asz" % (DOCROOT,blogYear, blogMonth)

	fp = open(blogFileName)
	fullFile = string.join(fp.readlines(),'')
	fp.close()

	blogPat = re.compile(r'<a name="%s"></a>\s*<p><b>([^<]*)</b><br></br>(.*?)<p class="blogend">([^<]+)<' % blogID, re.DOTALL)
	allMatches = blogPat.search(fullFile)
	if allMatches:
		blogSubject = allMatches.group(1)
		fullBlogEntry = allMatches.group(2)
		timeStamp = allMatches.group(3)
	else:
		printFinalPage("<p>Sorry, no blog entry with that ID was found</p>")

	return(blogSubject,fullBlogEntry,timeStamp)



def displayCommentPage(entryID, commentSender, senderEmail, senderURL, commentBody):
	"""Generate preview of the final blog"""

	global CGIURL

	blogSubject,fullBlogEntry,blogTimeStamp = getBlogBody(entryID)

	escBody = string.replace(commentBody,'<','&lt;')
	escBody = string.replace(escBody,'>','&gt;')

	commentBody = string.replace(commentBody,'\n','<br></br>\n')
	todaysDate,currentTime = getTimes()

	blogYear,blogMonth,fullDate = getIndexData(entryID)

	if commentBody == '':
		divSection = ''
	else:
		divSection = '''
								<div>
								<p><b>On %s, at %s, <a href="%s">%s</a> said:</b></p>
								<p>%s</p>
								</div>
''' % (todaysDate, currentTime, senderURL, commentSender, commentBody)

	previewPage = '''<title>Comments for Blog Entry %s</title><h5>%s</h5>
<p><b>%s</b><br></br>
%s
								<p class="blogend">%s </p>
								<hr></hr>
%s
								<form action="%s/comments.py" method="post">
									<input name="blid" type="hidden" value="%s">
									<p><b>Name:</b> <br></br><input name="sender" value="%s"></p>
									<p><b>Email:</b> <br></br><input name="email" value="%s"></p>
									<p><b>Blog URL:</b> <br></br><input name="url" value="%s"></p>
									<p><b>Comment:</b><br></br>
									<textarea cols="50" rows="10" name="comment">%s</textarea>
									<br></br>
									<input value="Send" name="confirm" type="submit"><input value="Preview" name="preview" type="submit"><input value="Cancel" name="cancel" type="submit"></p>
								</form>
''' % (entryID, fullDate, blogSubject, fullBlogEntry, blogTimeStamp, divSection, CGIURL, entryID, commentSender, senderEmail, senderURL, escBody)

	printFinalPage(previewPage)
        return()


def getTimes():
	"""Generate the desired date and time formats for the blog entry"""

	import time

	currentHour = time.strftime("%H", time.localtime(time.time()))
	if atoi(currentHour) < 12:
		timeSuffix = 'am'
	else:
		timeSuffix = 'pm'

	currentMinute = time.strftime("%M", time.localtime(time.time()))

	dayOfMonth = time.strftime("%d", time.localtime(time.time()))
	if atoi(dayOfMonth) < 10:
		dayOfMonth = string.replace(dayOfMonth,'0','')
	if dayOfMonth == '1':
		dayOfMonth = '1st';
	elif dayOfMonth == '2':
		dayOfMonth = '2nd';
	elif dayOfMonth == '3':
		dayOfMonth = '3rd';
	elif dayOfMonth == '21':
		dayOfMonth = '21st';
	elif dayOfMonth == '22':
		dayOfMonth = '22nd';
	elif dayOfMonth == '23':
		dayOfMonth = '23rd';
	elif dayOfMonth == '31':
		dayOfMonth = '31st';
	else:
		dayOfMonth = '%sth' % dayOfMonth
	monthOfYear = time.strftime("%B", time.localtime(time.time()))
	decimalYear = time.strftime("%Y", time.localtime(time.time()))

	blogDate = '%s %s %s' % (dayOfMonth, monthOfYear, decimalYear)
	blogTime = '%s:%s%s' % (currentHour, currentMinute, timeSuffix)

	return(blogDate, blogTime)



def sendComment(blID, commentSender, senderEmail, senderURL, commentBody):
	"""Get input from somewhere and insert it in the main page, together with
	the time stamp"""

	global DOCROOT
	global MAINURL
	global CGIURL

	todaysDate,currentTime = getTimes()

	commentBody = string.replace(commentBody,'\n','<br></br>\n')
	commentHTML = '''
<div>
<p><b>On %s, at %s, <a href="%s">%s</a> said:</b></p>

<p>%s</p>

</div>

<!-- NEW COMMENTS GO HERE -->''' %(todaysDate, currentTime, senderURL, commentSender, commentBody)

	blogYear,blogMonth,fullDate = getIndexData(blID)
	commentFileName = '%s/%s/%s/comments-%s.asz' %(DOCROOT,blogYear,blogMonth,blID)
	commentURL = '%s/%s/%s/comments-%s.html' %(MAINURL,blogYear,blogMonth,blID)

	if os.path.exists(commentFileName):
		c = open(commentFileName)
		oldComments = string.join(c.readlines(),'')
		c.close()
		newData = string.replace(oldComments,'<!-- NEW COMMENTS GO HERE -->',commentHTML)
		n = open(commentFileName,'w')
		n.write(newData)
		n.close()
	else:
		blogSubject,fullBlogEntry,blogTimeStamp = getBlogBody(blID)
		fullHTMLBlock = '''<title>Comments for Blog Entry %s</title><h5>%s</h5>
<p><b>%s</b><br></br>
%s
								<p class="blogend">%s </p>
								<hr></hr>
%s
								<form action="%s/comments.py" method="post">
									<input name="blid" type="hidden" value="%s">
									<p><b>Name:</b> <br></br><input name="sender"></p>
									<p><b>Email:</b> <br></br><input name="email"></p>
									<p><b>Blog URL:</b> <br></br><input name="url"></p>
									<p><b>Comment:</b><br></br>
									<textarea cols="50" rows="10" name="comment"></textarea>
									<br></br>
									<input value="Send" name="confirm" type="submit"><input value="Preview" name="preview" type="submit"><input value="Cancel" name="cancel" type="submit"></p>
								</form>
''' % (blID, fullDate, blogSubject, fullBlogEntry, blogTimeStamp, commentHTML, CGIURL, blID)

		c = open(commentFileName, 'w')
		c.write(fullHTMLBlock)
		c.close()

	incrementCommentLink(blID)
	webUpdateCommand = 'sudo -u sajjad /home/sajjad/bin/webupdate.py'
	upd = os.popen(webUpdateCommand)
	upd.close()
	mailComment(blID, commentSender, senderEmail, commentURL)
	printRedirPage(commentURL)
	return()



def mailComment(blID, senderName, senderEmail, commentURL):
	"""Mail the commentor's info and the URL to the comment
	page to the admin"""

	import smtplib

	mailBody = '''
Comment from %s on blog entry %s:

%s
''' %(senderName, blID, commentURL)

	smtpServer = 'localhost'
	if senderEmail == '':
		senderEmail = 'webmaster@zaidi.jp'
	fromAddress = '%s' % senderEmail
	toAddress = 'sajjad@zaidi.jp'
	mailSubject = 'Comment from %s' % senderName

	fullMessage = '''From: %s
To: %s
Cc: 
Bcc: 
Subject: %s 
Reply-To: 

%s
''' %(fromAddress, toAddress, mailSubject, mailBody)
	try:
		server = smtplib.SMTP('%s' % smtpServer)
		server.sendmail('%s' % fromAddress, '%s' % toAddress, fullMessage)
		server.quit
	except:
		printFinalPage('<p>Error sending comment. Please contact the webmaster</p>')
	return()



def printFinalPage(pageContent):
	global DOCROOT

	fp = open('%s/template.html' % DOCROOT)
	fullTemplate = string.join(fp.readlines(), '')
	fp.close()
	
	tPat = re.compile(r'<title>([^<]*)</title>')
	titleMatch = tPat.search(pageContent)
	if titleMatch:
		pageTitle = titleMatch.group(1)
		pageContent = string.replace(pageContent, '<title>%s</title>' % pageTitle, '')
	else:
		pageTitle = 'Sajjad\'s Japan Site'

	finalPage = string.replace(fullTemplate, '#INSERT_BODY_HERE#', pageContent)
	finalPage = string.replace(finalPage, '#PUT_TITLE_HERE#', pageTitle)

        print 'Content-type: text/html\n\n'
        print finalPage
	sys.exit(0)
	return()



def printRedirPage(redirURL):
	"""Redirect to specified page"""

        mainPageRedirect = '''
<html>
        <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
		<meta http-equiv="refresh" content="0;url=%s">
                <title>Redirect to main page</title>
        </head>
        <body>
        </body>
</html>''' % redirURL
        print 'Content-type: text/html\n\n'
	print mainPageRedirect
	sys.exit(0)
        return()


def incrementCommentLink(blID):
	"""Update the comment link on the main page to
	display the number of comments received"""

	global DOCROOT

	blogYear,blogMonth,fullDate = getIndexData(blID)
	blogFileName = "%s/%s/%s/index.asz" % (DOCROOT,blogYear, blogMonth)

	fp = open(blogFileName)
	fullFile = string.join(fp.readlines(),'')
	fp.close()

	comPat = re.compile(r'blogid=%s">Comments(.*?)</a>' % blID, re.DOTALL)
	comMatch = comPat.search(fullFile)
	if comMatch:
		matchResult = comMatch.group(1)
		if matchResult == '':
			newCommentNo = 1
			fullFile = string.replace(fullFile,'blogid=%s">Comments</a>' %(blID),'blogid=%s">Comments(%s)</a>' %(blID, newCommentNo))
		else:
			matchResult = string.replace(matchResult,'(','')
			matchResult = string.replace(matchResult,')','')
			oldCommentNo = atoi(matchResult)
			newCommentNo = oldCommentNo + 1
			fullFile = string.replace(fullFile,'blogid=%s">Comments(%s)</a>' %(blID, oldCommentNo),'blogid=%s">Comments(%s)</a>' %(blID, newCommentNo))
		c = open(blogFileName,'w')
		c.write(fullFile)
		c.close()
	return()



###########################################
##                 Start                 ##
###########################################

# Check how we were accessesd
if os.environ.has_key("GATEWAY_INTERFACE"):
	parseCGIForm()

sys.exit(0)
